@@ -43,15 +43,14 @@ namespace KDecoration2
 namespace Oxygen
 {
     class SizeGrip;
-    class TitleAnimationData;
-
-
-
 
     class Decoration : public KDecoration2::Decoration
     {
         Q_OBJECT
 
+        //* declare active state opacity
+        Q_PROPERTY( qreal opacity READ opacity WRITE setOpacity )
+
         public:
 
         //* constructor
@@ -73,6 +72,26 @@ namespace Oxygen
         //* button height
         int buttonHeight() const;
 
+        //*@name active state change animation
+        //@{
+        bool isAnimated( void ) const
+        { return m_animation->state() == QPropertyAnimation::Running; }
+
+        void setOpacity( qreal );
+
+        qreal opacity( void ) const
+        { return m_opacity; }
+
+        //@}
+
+        //*@name colors
+        //@{
+
+        QColor titlebarTextColor(const QPalette&) const;
+        QColor titlebarTextColor(const QPalette& palette, bool active ) const;
+        QColor titlebarContrastColor(const QPalette& palette ) const;
+        QColor titlebarContrastColor(const QColor& color ) const;
+
         //@}
 
         public Q_SLOTS:
@@ -81,57 +100,30 @@ namespace Oxygen
         private Q_SLOTS:
         void reconfigure();
         void recalculateBorders();
-        void updateButtonPositions();
+        void updateButtonsGeometry();
         void updateTitleBar();
+        void updateAnimationState();
+        void updateSizeGripVisibility();
+        void updateShadow();
 
         private:
-        QRect captionRect() const;
+
+        //* return the rect in which caption will be drawn
+        QPair<QRect,Qt::Alignment> captionRect( void ) const;
 
         void createButtons();
 
-        void createShadow();
-
-        bool glowIsAnimated() const {return false;}
-        qreal glowIntensity() const {return 1.0;}
-
-        //* text color
-        QColor titlebarTextColor(const QPalette&) const;
-
-        //* text color
-        QColor titlebarTextColor(const QPalette& palette, bool windowActive, bool itemActive ) const;
-
-        //* text color
-        QColor titlebarContrastColor(const QPalette& palette ) const;
-
-        //* text color
-        QColor titlebarContrastColor(const QColor& color ) const;
-
         //* window background
         void renderWindowBackground( QPainter*, const QRect&, const QPalette& ) const;
 
         //* window border
-        // this draws a "blue" border around active window
         void renderWindowBorder( QPainter*, const QRect&, const QPalette& ) const;
 
-        //* title outline
-        void renderTitleOutline( QPainter*, const QRect&, const QPalette& ) const;
-
         //* title text
-        /** second color, if valid, is for contrast pixel */
-        void renderTitleText( QPainter*, const QRect&, const QColor&, const QColor& = QColor() ) const;
-
-        //* title text
-        /** second color, if valid, is for contrast pixel */
-        void renderTitleText( QPainter*, const QRect&, const QString&, const QColor&, const QColor& = QColor(), bool elide = true ) const;
-
-        //* title text
-        QPixmap renderTitleText( const QRect&, const QString&, const QColor&, bool elide = true ) const;
+        void renderTitleText( QPainter*, const QPalette& ) const;
 
         //* corners
-        void renderCorners( QPainter*, const QRect &frame, const QPalette &) const;
-
-        bool hideTitleBar() const
-        {return false;}
+        void renderCorners( QPainter*, const QRect&, const QPalette& ) const;
 
         //*@name border size
         //@{
@@ -145,7 +137,8 @@ namespace Oxygen
         inline bool isMaximized( void ) const;
         inline bool isMaximizedHorizontally( void ) const;
         inline bool isMaximizedVertically( void ) const;
-        //@}
+        inline bool hideTitleBar( void ) const;
+       //@}
 
         //*@name size grip
         //@{
@@ -164,7 +157,12 @@ namespace Oxygen
         //* size grip widget
         SizeGrip *m_sizeGrip = nullptr;
 
-        TitleAnimationData *_titleAnimationData;
+        //* active state change animation
+        QPropertyAnimation *m_animation;
+
+        //* active state change opacity
+        qreal m_opacity = 0;
+
     };
 
     bool Decoration::hasNoBorders( void ) const
@@ -182,6 +180,7 @@ namespace Oxygen
     bool Decoration::isMaximized( void ) const { return client().data()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
     bool Decoration::isMaximizedHorizontally( void ) const { return client().data()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
     bool Decoration::isMaximizedVertically( void ) const { return client().data()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
+    bool Decoration::hideTitleBar( void ) const { return m_internalSettings->hideTitleBar() && !client().data()->isShaded(); }
 
 }
 
