@@ -33,11 +33,24 @@
 namespace Oxygen
 {
 
+    //*@name convenience typedef
+    //@{
+
+    #if QT_VERSION >= 0x050000
+    //* scoped pointer convenience typedef
+    template <typename T> using WeakPointer = QPointer<T>;
+    #else
+    //* scoped pointer convenience typedef
+    template <typename T> using WeakPointer = QWeakPointer<T>;
+    #endif
+
     //* disable QStringLiteral for older Qt version
     #if QT_VERSION < 0x050000
     using QStringLiteral = QString;
     #endif
 
+    //@}
+
     //* this should move to some global declaration
     typedef QSharedPointer<Configuration> ConfigurationPtr;
     typedef QList<ConfigurationPtr> ConfigurationList;
